==> eslint-config-zals-0.1.5.tgz: package/rules/custom.js <==

module.exports = {
    extends : [
        'eslint:all', 'plugin:jsx-a11y/recommended',
    ],

    rules : {
        'array-bracket-newline'      : [ 2, 'consistent' ],
        'array-bracket-spacing'      : [ 2, 'always', { objectsInArrays: false }],
        'array-callback-return'      : [ 2 ],
        'array-element-newline'      : [ 2, { minItems: null, multiline: true }],
        'arrow-body-style'           : [ 2, 'as-needed' ],
        'block-spacing'              : [ 2 ],
        'brace-style'                : [ 2, 'stroustrup' ],
        'callback-return'            : [ 0 ],
        'capitalized-comments'       : [ 0 ],
        'class-methods-use-this'     : [ 0 ],
        'comma-dangle'               : [ 2, 'always-multiline' ],
        'consistent-return'          : [ 0 ],
        'curly'                      : [ 2, 'multi-or-nest' ],
        'dot-location'               : [ 2, 'property' ],
        'eol-last'                   : [ 2, 'always' ],
        'func-style'                 : [ 0 ],
        'id-length'                  : [ 2, { exceptions: [ 'e', 'i', 'k', 'x', 'X', 'z', 'Z' ], min: 2 }],
        'init-declarations'          : [ 2, 'always' ],
        'jsx-quotes'                 : [ 2, 'prefer-double' ],
        'key-spacing'                : [ 2, { align: { afterColon: true, beforeColon: true, on: 'colon' }, multiLine: { afterColon: true, beforeColon: true }, singleLine: { afterColon: true, beforeColon: false } }],
        'keyword-spacing'            : [ 2, { after: true, before: true }],
        'lines-around-comment'       : [ 0, { allowBlockStart: true, allowClassStart: true, allowObjectStart: true, beforeBlockComment: false }],
        'max-len'                    : [ 2, { code: 800, ignoreComments: true, ignoreRegExpLiterals: true, ignoreStrings: true, ignoreTemplateLiterals: true, ignoreTrailingComments: true, ignoreUrls: true }],
        'max-lines'                  : [ 0 ],
        'max-lines-per-function'     : [ 0 ],
        'max-nested-callbacks'       : [ 2, { max: 2 }],
        'max-params'                 : [ 2, 10 ],
        'max-statements'             : [ 0 ],
        'max-statements-per-line'    : [ 2, { max: 1 }],
        'multiline-comment-style'    : [ 0 ],
        'multiline-ternary'          : [ 0 ],
        'new-parens'                 : [ 2 ],
        'newline-before-return'      : [ 2 ],
        'newline-per-chained-call'   : [ 2, { ignoreChainWithDepth: 3 }],
        'no-bitwise'                 : [ 1, { allow: [ '~' ], int32Hint: true }],
        'no-console'                 : [ 1 ],
        'no-constant-condition'      : [ 2 ],
        'no-delete-var'              : [ 2 ],
        'no-dupe-args'               : [ 2 ],
        'no-empty'                   : [ 2 ],
        'no-empty-function'          : [ 2, { allow: [ 'arrowFunctions', 'constructors', 'functions', 'getters', 'methods', 'setters' ] }],
        'no-ex-assign'               : [ 2 ],
        'no-extra-parens'            : [ 2, 'all', { enforceForArrowConditionals: false, ignoreJSX: 'all', nestedBinaryExpressions: false, returnAssign: false }],
        'no-implicit-coercion'       : [ 2, { allow: [ '+', '!!', '~' ] }],
        'no-invalid-this'            : [ 0 ],
        'no-magic-numbers'           : [ 0 ],
        'no-multi-spaces'            : [ 2, { exceptions: { ImportDeclaration: true, VariableDeclarator: true } }],
        'no-multiple-empty-lines'    : [ 1, { max: 5, maxBOF: 2, maxEOF: 0 }],
        'no-negated-condition'       : [ 1 ],
        'no-new'                     : [ 0 ],
        'no-plusplus'                : [ 2, { allowForLoopAfterthoughts: true }],
        'no-process-env'             : [ 0 ],
        'no-process-exit'            : [ 0 ],
        'no-prototype-builtins'      : [ 0 ],
        'no-regex-spaces'            : [ 2 ],
        'no-shadow'                  : [ 2 ],
        'no-shadow-restricted-names' : [ 2 ],
        'no-sparse-arrays'           : [ 2 ],
        'no-sync'                    : [ 0 ],
        'no-ternary'                 : [ 0 ],
        'no-undef'                   : [ 2 ],
        'no-undef-init'              : [ 2 ],
        'no-underscore-dangle'       : [ 0, { allowAfterSuper: true, allowAfterThis: true, enforceInMethodNames: false }],
        'no-unreachable'             : [ 0 ],
        'no-unsafe-negation'         : [ 2 ],
        'no-unused-expressions'      : [ 0 ],
        'no-unused-vars'             : [ 1, { vars: 'all', varsIgnorePattern: '(React|window)' }],
        'no-use-before-define'       : [ 2 ],
        'no-void'                    : [ 0 ],
        'no-warning-comments'        : [ 0 ],
        'object-curly-newline'       : [ 2, { consistent: true, multiline: true }],
        'object-curly-spacing'       : [ 2, 'always', { arraysInObjects: true, objectsInObjects: true }],
        'object-property-newline'    : [ 2, { allowAllPropertiesOnSameLine: true }],
        'object-shorthand'           : [ 2, 'always', { avoidExplicitReturnArrows: true }],
        'one-var'                    : [ 2, 'never' ],
        'padded-blocks'              : [ 2, { blocks: 'never', classes: 'always', switches: 'never' }],
        'quote-props'                : [ 2, 'consistent-as-needed' ],
        'quotes'                     : [ 2, 'single' ],
        'require-unicode-regexp'     : [ 0 ],
        'sort-imports'               : [ 2, { ignoreCase: true, ignoreMemberSort: false, memberSyntaxSortOrder: [ 'none', 'all', 'single', 'multiple' ] }],
        'sort-keys'                  : [ 0 ],
        'sort-vars'                  : [ 2, { ignoreCase: true }],
        'space-before-blocks'        : [ 2 ],
        'space-infix-ops'            : [ 2 ],
        'spaced-comment'             : [ 2, 'always' ],
        'valid-jsdoc'                : [ 0 ],
        'valid-typeof'               : [ 2 ],
        'wrap-regex'                 : [ 2 ],
    },
};

==> eslint-config-zals-0.1.6.tgz: package/rules/custom.js <==

module.exports = {
    extends : [
        'eslint:all', 'plugin:jsx-a11y/recommended',
    ],

    rules : {
        'array-bracket-newline'      : [ 2, 'consistent' ],
        'array-bracket-spacing'      : [ 2, 'always', { objectsInArrays: false }],
        'array-callback-return'      : [ 2 ],
        'array-element-newline'      : [ 2, { minItems: null, multiline: true }],
        'arrow-body-style'           : [ 2, 'as-needed' ],
        'block-spacing'              : [ 2 ],
        'brace-style'                : [ 2, 'stroustrup' ],
        'callback-return'            : [ 0 ],
        'capitalized-comments'       : [ 0 ],
        'class-methods-use-this'     : [ 0 ],
        'comma-dangle'               : [ 2, 'always-multiline' ],
        'consistent-return'          : [ 0 ],
        'curly'                      : [ 2, 'multi-or-nest' ],
        'default-case'               : [ 0 ],
        'dot-location'               : [ 2, 'property' ],
        'eol-last'                   : [ 2, 'always' ],
        'func-style'                 : [ 0 ],
        'id-length'                  : [ 2, { exceptions: [ 'e', 'i', 'k', 'x', 'X', 'z', 'Z' ], min: 2 }],
        'init-declarations'          : [ 2, 'never' ],
        'jsx-quotes'                 : [ 2, 'prefer-double' ],
        'key-spacing'                : [ 2, { align: { afterColon: true, beforeColon: true, on: 'colon' }, multiLine: { afterColon: true, beforeColon: true }, singleLine: { afterColon: true, beforeColon: false } }],
        'keyword-spacing'            : [ 2, { after: true, before: true }],
        'lines-around-comment'       : [ 0, { allowBlockStart: true, allowClassStart: true, allowObjectStart: true, beforeBlockComment: false }],
        'max-len'                    : [ 2, { code: 800, ignoreComments: true, ignoreRegExpLiterals: true, ignoreStrings: true, ignoreTemplateLiterals: true, ignoreTrailingComments: true, ignoreUrls: true }],
        'max-lines'                  : [ 0 ],
        'max-lines-per-function'     : [ 0 ],
        'max-nested-callbacks'       : [ 2, { max: 2 }],
        'max-params'                 : [ 2, 10 ],
        'max-statements'             : [ 0 ],
        'max-statements-per-line'    : [ 2, { max: 1 }],
        'multiline-comment-style'    : [ 0 ],
        'multiline-ternary'          : [ 0 ],
        'new-parens'                 : [ 2 ],
        'newline-before-return'      : [ 2 ],
        'newline-per-chained-call'   : [ 2, { ignoreChainWithDepth: 3 }],
        'no-bitwise'                 : [ 1, { allow: [ '~' ], int32Hint: true }],
        'no-console'                 : [ 1 ],
        'no-constant-condition'      : [ 2 ],
        'no-delete-var'              : [ 2 ],
        'no-dupe-args'               : [ 2 ],
        'no-empty'                   : [ 2 ],
        'no-empty-function'          : [ 2, { allow: [ 'arrowFunctions', 'constructors', 'functions', 'getters', 'methods', 'setters' ] }],
        'no-ex-assign'               : [ 2 ],
        'no-extra-parens'            : [ 2, 'all', { enforceForArrowConditionals: false, ignoreJSX: 'all', nestedBinaryExpressions: false, returnAssign: false }],
        'no-implicit-coercion'       : [ 2, { allow: [ '+', '!!', '~' ] }],
        'no-invalid-this'            : [ 0 ],
        'no-magic-numbers'           : [ 0 ],
        'no-multi-spaces'            : [ 2, { exceptions: { ImportDeclaration: true, VariableDeclarator: true } }],
        'no-multiple-empty-lines'    : [ 1, { max: 5, maxBOF: 2, maxEOF: 0 }],
        'no-negated-condition'       : [ 1 ],
        'no-new'                     : [ 0 ],
        'no-plusplus'                : [ 2, { allowForLoopAfterthoughts: true }],
        'no-process-env'             : [ 0 ],
        'no-process-exit'            : [ 0 ],
        'no-prototype-builtins'      : [ 0 ],
        'no-regex-spaces'            : [ 2 ],
        'no-shadow'                  : [ 2 ],
        'no-shadow-restricted-names' : [ 2 ],
        'no-sparse-arrays'           : [ 2 ],
        'no-sync'                    : [ 0 ],
        'no-ternary'                 : [ 0 ],
        'no-undef'                   : [ 2 ],
        'no-undef-init'              : [ 2 ],
        'no-underscore-dangle'       : [ 0, { allowAfterSuper: true, allowAfterThis: true, enforceInMethodNames: false }],
        'no-unreachable'             : [ 0 ],
        'no-unsafe-negation'         : [ 2 ],
        'no-unused-expressions'      : [ 0 ],
        'no-unused-vars'             : [ 1, { vars: 'all', varsIgnorePattern: '(React|window)' }],
        'no-use-before-define'       : [ 2 ],
        'no-void'                    : [ 0 ],
        'no-warning-comments'        : [ 0 ],
        'object-curly-newline'       : [ 2, { consistent: true, multiline: true }],
        'object-curly-spacing'       : [ 2, 'always', { arraysInObjects: true, objectsInObjects: true }],
        'object-property-newline'    : [ 2, { allowAllPropertiesOnSameLine: true }],
        'object-shorthand'           : [ 2, 'always', { avoidExplicitReturnArrows: true }],
        'one-var'                    : [ 2, 'never' ],
        'padded-blocks'              : [ 2, { blocks: 'never', classes: 'always', switches: 'never' }],
        'quote-props'                : [ 2, 'consistent-as-needed' ],
        'quotes'                     : [ 2, 'single' ],
        'require-unicode-regexp'     : [ 0 ],
        'sort-imports'               : [ 2, { ignoreCase: true, ignoreMemberSort: false, memberSyntaxSortOrder: [ 'none', 'all', 'single', 'multiple' ] }],
        'sort-keys'                  : [ 0 ],
        'sort-vars'                  : [ 2, { ignoreCase: true }],
        'space-before-blocks'        : [ 2 ],
        'space-infix-ops'            : [ 2 ],
        'spaced-comment'             : [ 2, 'always' ],
        'valid-jsdoc'                : [ 0 ],
        'valid-typeof'               : [ 2 ],
        'wrap-regex'                 : [ 2 ],
    },
};
